# Generated by Django 5.0.3 on 2024-05-06 16:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0009_alter_access_unique_together"),
    ]

    operations = [
        migrations.AddField(
            model_name="object",
            name="obvious",
            field=models.BooleanField(default=True),
        ),
    ]
